fetch_column_collation

Function fetch_column_collation 

async fn fetch_column_collation<Q>(
    conn: &mut Q,
    table: &MySqlTableName,
    column: &str,
) -> Result<Option<(String, String)>, TransientError>
where Q: Queryable,
Character set and collation of column in table, or None if the column has no collation (numeric/temporal types sort independently of collation) or is absent.