try_extract_single_column_pk

Function try_extract_single_column_pk 

fn try_extract_single_column_pk(
    desc: &MySqlTableDesc,
) -> Option<(String, SqlScalarType)>
The raw (unquoted) name and scalar type of a table’s primary key, when it is a single column. Callers quote the name for SQL predicates and use the raw name for information_schema lookups.