async fn compute_sampled_splits(
tx: &mut Transaction<'_>,
table: &MySqlTableName,
raw_col: &str,
scalar_type: &SqlScalarType,
worker_count: usize,
row_count: u64,
settings: &PartitionSettings,
) -> Result<Option<PkBoundaries>, TransientError>Expand description
Attempts to compute roughly even boundaries for primary keys. Returns None if the column type is unsupported or boundaries couldn’t be estimated for some reason. Currently only supports CHAR/VARCHAR columns with up to 768 characters with utf8mb4_bin collation.